@@ -31,7 +31,7 @@ compareRaster <- function(x, ..., extent=TRUE, rowcol=TRUE, crs=TRUE, res=FALSE,
 		return(result)
 	}	
 	minres <- min(res(objects[[1]]))
-	proj1 <- projection(objects[[1]])
+	proj1 <- .getCRS(objects[[1]])
 	ext1 <- extent(objects[[1]])
 	ncol1 <- ncol(objects[[1]])
 	nrow1 <- nrow(objects[[1]])
@@ -60,18 +60,18 @@ compareRaster <- function(x, ..., extent=TRUE, rowcol=TRUE, crs=TRUE, res=FALSE,
 			}
 		}
 		if (crs) {
-			thisproj <- projection(objects[[i]])
+			thisproj <-.getCRS(objects[[i]])
 			if (is.na(proj1)) {
 				proj1 <- thisproj
 			} else {
 				crs <- try (compareCRS(proj1, thisproj, unknown=TRUE), silent=TRUE)
 				if (inherits(crs, "try-error")) {
-					if (stopiffalse) { stop("invalid CRS") }
-					if (showwarning) { warning("invalid CRS") }
+					if (stopiffalse) { stop("invalid crs") }
+					if (showwarning) { warning("invalid crs") }
 				} else if (!crs) {
 					result <- FALSE
-					if (stopiffalse) { stop("different CRS") }
-					if (showwarning) { warning("different CRS") }
+					if (stopiffalse) { stop("different crs") }
+					if (showwarning) { warning("different crs") }
 				}
 			}
 		}
