@@ -3,10 +3,6 @@
 # Version 0.9
 # Licence GPL v3
 
-if (!isGeneric("contour")) {
-	setGeneric("contour", function(x,...)
-		standardGeneric("contour"))
-}	
 
 setMethod("contour", signature(x='RasterLayer'), 
 	function(x, maxpixels=100000, ...)  {
@@ -27,7 +23,7 @@ rasterToContour <- function(x, maxpixels=100000, ...) {
 		res <- vector(mode="list", length=n)
 		for (i in 1:n) {
 			crds <- cbind(cL[[i]][[2]], cL[[i]][[3]])
-			res[[i]] <- Line(coords=crds)
+			res[[i]] <- sp::Line(coords=crds)
 		}
 		res
 	}
@@ -40,10 +36,10 @@ rasterToContour <- function(x, maxpixels=100000, ...) {
     IDs <- paste("C", 1:m, sep = "_")
     row.names(df) <- IDs
     for (i in 1:m) {
-        res[[i]] <- Lines(.contourLines2LineList(cL[cLstack[[i]]]), ID = IDs[i])
+        res[[i]] <- sp::Lines(.contourLines2LineList(cL[cLstack[[i]]]), ID = IDs[i])
     }
-    SL <- SpatialLines(res, proj4string = projection(x, asText=FALSE))
-    SpatialLinesDataFrame(SL, data = df)
+    SL <- sp::SpatialLines(res,  proj4string= .getCRS((x)))
+    sp::SpatialLinesDataFrame(SL, data = df)
 	
 }
 
@@ -67,8 +63,8 @@ filledContour <- function(x, y=1, maxpixels=100000, ...) {
 		} else {
 			asp <- 1
 		}		
-		filled.contour(x=X,y=Y,z=Z,asp=asp,...)
+		graphics::filled.contour(x=X,y=Y,z=Z,asp=asp,...)
 	} else {
-		filled.contour(x=X,y=Y,z=Z,...)
+		graphics::filled.contour(x=X,y=Y,z=Z,...)
 	}
 }
